@@ -17,8 +17,17 @@ def ts_to_datetime(ts, timezone):
     dt = pytz.utc.localize(dt, is_dst=None).astimezone(py_zone)
     return dt
 
+def datetime_to_ts(dt):
+    """ convert any datetime to timestamp """
+    return int(dt.timestamp())
+
 def ts_to_str(ts, timezone, strftime="%b %d %Y %H:%M:%S"):
     """ from ts (UTC), it converts date to timezone and return string using strftime
     """
     dt_local = ts_to_datetime(ts, timezone)
-    return dt_local.strftime(strftime)
\ No newline at end of file
+    return dt_local.strftime(strftime)
+
+def datetime_to_str(dt, timezone, strftime="%b %d %Y %H:%M:%S"):
+    """ convert from datetime to string using defined format """
+    ts = datetime_to_ts(dt)
+    return ts_to_str(ts, timezone, strftime)
\ No newline at end of file
